@@ -1,5 +1,6 @@
 from pathlib import Path
 
+from pyrrhic.repo.index import Index
 from pyrrhic.repo.repository import Repository, get_masterkey
 
 REPO_BASE = "restic_test_repositories"
@@ -12,8 +13,7 @@ def test_load_index():
         get_masterkey(Path(REPO_BASE) / "restic_test_repository", "password"),
     )
     indexes = repo.get_index(INDEX_ID)
-    assert next(indexes, None)
-    assert next(indexes, None) is None
+    assert type(indexes) == Index
 
 
 def test_load_indexes():
@@ -22,4 +22,4 @@ def test_load_indexes():
         get_masterkey(Path(REPO_BASE) / "restic_test_repository", "password"),
     )
     indexes = repo.get_index()
-    assert next(indexes)
+    assert type(indexes) == Index
