@@ -8,12 +8,12 @@ import pytest
 REPO_BASE = Path("restic_test_repositories")
 SNAPSHOT_ID = "dd62b535d10bd8f24440cc300a868d6bf2f472859f1218883b0a6faca364c10c"
 KEY_ID = "98f9e68226bf15a8e9616632df7c9df543e255b388bfca1cde0218009b77cdeb"
-KEY_FILE = f"{REPO_BASE}/restic_test_repository/keys/{KEY_ID}"
+KEY_PATH = Path(f"{REPO_BASE}/restic_test_repository/keys/{KEY_ID}")
 
 
 @pytest.fixture
 def masterkey():
-    return get_masterkey(KEY_FILE, b"password")
+    return get_masterkey(KEY_PATH, b"password")
 
 
 def test_load_snapshot(masterkey):
